==> hyades.source_3.1.0_20041019_1201.zip: org/eclipse/hyades/perfmon/perfmon/internal/PerfmonStatisticalImageProvider.java <==
/**********************************************************************
 * Copyright (c) 2003,2004 Scapa Technologies Limited and others
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Common Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/cpl-v10.html
 * 
 * Contributors: 
 * Scapa Technologies Limited - Initial API and implementation
 **********************************************************************/
package org.eclipse.hyades.perfmon.perfmon.internal;

import org.eclipse.hyades.perfmon.ImageManager;
import org.eclipse.hyades.perfmon.PerfmonPlugin;
import org.eclipse.hyades.statistical.ui.editor.internal.StatConStatisticalImageProvider;

import org.eclipse.swt.graphics.Image;
import org.eclipse.hyades.models.hierarchy.*;
import org.eclipse.hyades.model.statistical.*;

public class PerfmonStatisticalImageProvider implements StatConStatisticalImageProvider {
	
	private boolean isOurs(TRCAgent agent) {
		//NOTE! MUST BE LOWER CASE MATCH
		return agent.getName().toLowerCase().startsWith(PerfmonConstants.AGENT_PREFIX.toLowerCase());
	}
	
	public Image getImage(SDDescriptor descriptor) {
		//we dont do anything here
		return null;
	}
	public Image getImage(SDDescriptor descriptor, TRCAgent agent) {
/*	StatCon does this for us now
		if (isOurs(agent)) {
			if (descriptor.getId() != null) {
				if (descriptor.getId().indexOf('C') != -1) 
				{	
					return PerfmonPlugin.img.getImage(ImageManager.IMG_PERFMON_COUNTER);
				}
				else {
				}
			}
		}
		*/
		return null;
	}
}

==> hyades.source_3.3.0_20050623_2150.zip: org/eclipse/hyades/perfmon/perfmon/internal/PerfmonStatisticalImageProvider.java <==
/**********************************************************************
 * Copyright (c) 2005 Scapa Technologies Limited and others
 * 
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Contributors: 
 * Scapa Technologies Limited - Initial API and implementation
 **********************************************************************/
package org.eclipse.hyades.perfmon.perfmon.internal;

import org.eclipse.hyades.model.statistical.SDDescriptor;
import org.eclipse.hyades.models.hierarchy.TRCAgent;
import org.eclipse.hyades.statistical.ui.editor.internal.StatConStatisticalImageProvider;
import org.eclipse.swt.graphics.Image;

public class PerfmonStatisticalImageProvider implements StatConStatisticalImageProvider {
	
	private boolean isOurs(TRCAgent agent) {
		//NOTE! MUST BE LOWER CASE MATCH
		return agent.getName().toLowerCase().startsWith(PerfmonConstants.AGENT_PREFIX.toLowerCase());
	}
	
	public Image getImage(SDDescriptor descriptor) {
		//we dont do anything here
		return null;
	}
	public Image getImage(SDDescriptor descriptor, TRCAgent agent) {
/*	StatCon does this for us now
		if (isOurs(agent)) {
			if (descriptor.getId() != null) {
				if (descriptor.getId().indexOf('C') != -1) 
				{	
					return PerfmonPlugin.img.getImage(ImageManager.IMG_PERFMON_COUNTER);
				}
				else {
				}
			}
		}
		*/
		return null;
	}
}
